Module diff

Module diff 

Semantic diff between two .env files.

Values for keys that match common sensitive patterns (SECRET, KEY, TOKEN, PASSWORD, PASS, PWD) are redacted with bullet characters so secrets are never echoed to the terminal.

Functions

run
Compare file_a and file_b and print a coloured semantic diff.