Thin wrappers around the age passphrase encrypt/decrypt primitives.
Both functions operate on raw byte slices so they are agnostic about file
format; the higher-level file I/O lives in crate::commands::encrypt.
Thin wrappers around the age passphrase encrypt/decrypt primitives.
Both functions operate on raw byte slices so they are agnostic about file
format; the higher-level file I/O lives in crate::commands::encrypt.